
# Slot: name




URI: [ks:Person_name](https://w3id.org/linkml/tests/kitchen_sink/Person_name)


## Domain and Range

[Person](Person.md) &#8594;  <sub>0..1</sub> [String](String.md)

## Parents

 *  is_a: [name](name.md)

## Children


## Used by

 * [Person](Person.md)
